Learn R Programming

spsmooth (version 1.1-3)

chicagoNMMAPS: Chicago 1987-2000 from the NMMAPS database

Description

Daily measurements of death, temperature, dewpoint, and PM10 pollution from Chicago, 1987 to 2000. Data taken from the NMMAPS database using NMMAPSdata, a package written by Roger Peng and available at: http://www.ihapss.jhsph.edu/data/NMMAPS/R/.

Usage

chicagoNMMAPS

Arguments

Format

A data frame indicating the date, temperature, dewpoint, and PM10 pollution from Chicago. Frame also includes the mask variable needed for estimating a sp basis, see spsmooth.

Examples

Run this code
    # This provides the code that generated this set originally using 
    # the now-deprecated 'NMMAPSlite' package, and is included here for historical
    # reference.
    # 
    # library("NMMAPSlite")
    # initDB()   # ** this creates a directory for a data archive
    # chic <- readCity("chic", collapseAge=TRUE)
    # chic <- chic[, c("date", "death", "time", "tmpd", "dptp", "dow", "pm10tmean")]
    # mask <- rep(FALSE, length(chic[, "pm10tmean"]))
    # mask[!is.na(chic[, "pm10tmean"])] <- TRUE
    # chic <- cbind(chic, mask)

    # save(chic, file="chicagoNMMAPS.RData")

Run the code above in your browser using DataLab